simplify writer node group
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 04ad09d5028a612ada6b3373debe86a1e607da92..1c4a65fceefe4651af47f7e1df2aa14f55484c9a 100644 (file)
--- a/write.h
+++ b/write.h
@@ -25,60 +25,73 @@ enum writer_enum {WRITER_ENUM};
  * decbribes one running instance of a writer
  */
 struct writer_node {
-/** points to the writer structure associated with this node */
-       struct writer *writer;
-/** writer-specific data */
+       /** points to the writer structure associated with this node */
+       struct writer *writer; /* FIXME: Should better be only the number */
+       /** writer-specific data */
        void *private_data;
-/** send that many bytes in one go */
+       /** send that many bytes in one go */
        int chunk_bytes;
-       struct task task;
        struct writer_node_group *wng;
+       /** the writer-specific configuration of this node */
+       void *conf;
 };
 
 /** describes one supported writer */
 struct writer {
-/**
- * the init function of the writer
- *
- * It must fill in all other function pointers of the given
- * writer structure.
- *
- */
-void (*init)(struct writer *w);
-/**
- *
- * open one instance of this writer
- *
- * This function should perform any work necessary to write the incoming
- * stream. If To this aim, it may allocate its private data structure and store
- * a pointer to that structure via the given writer_node paramenter.
- */
-int (*open)(struct writer_node *);
-/**
- *
- * write a chunk of audio data
- *
- * This is called from the driving application whenever a data block of \a
- * chunk_bytes is available. It must return the number of bytes consumed from
- * \a data on success, and negative on errors.
- *
- */
-int (*write)(char *data, size_t nbytes, struct writer_node *);
-void (*pre_select)(struct sched *s, struct task *t);
-void (*post_select)(struct sched *s, struct task *t);
-/**
- * close one instance of the writer
- *
- * This function is assumed to succeed.
- */
-void (*close)(struct writer_node *);
-/**
- * shutdown the writer
- *
- * This is a optional function pointer used for cleaning
- * up.
- */
-void (*shutdown)(struct writer_node *);
+       /**
+        * the init function of the writer
+        *
+        * It must fill in all other function pointers of the given
+        * writer structure.
+        *
+        */
+       void (*init)(struct writer *w);
+       /**
+        *
+        *
+        * the command line parser of the writer
+        *
+        * It should check whether the command line options given by \a options are
+        * valid.  On success, it should return a pointer to the writer-specific
+        * configuration data determined by \a options.  Note that this might be called
+        * more than once with different values of \a options.
+        *
+        */
+               void * (*parse_config)(char *options);
+       /**
+        *
+        * open one instance of this writer
+        *
+        * This function should perform any work necessary to write the incoming
+        * stream. If To this aim, it may allocate its private data structure and store
+        * a pointer to that structure via the given writer_node paramenter.
+        */
+       int (*open)(struct writer_node *);
+       /**
+        *
+        * write a chunk of audio data
+        *
+        * This is called from the driving application whenever a data block of \a
+        * chunk_bytes is available. It must return the number of bytes consumed from
+        * \a data on success, and negative on errors.
+        *
+        */
+       int (*write)(char *data, size_t nbytes, struct writer_node *);
+       int (*pre_select)(struct sched *s, struct writer_node *wn);
+       int (*post_select)(struct sched *s, struct writer_node *wn);
+       /**
+        * close one instance of the writer
+        *
+        * This function is assumed to succeed.
+        */
+       void (*close)(struct writer_node *);
+       /**
+        * shutdown the writer
+        *
+        * This is a optional function pointer used for cleaning
+        * up.
+        */
+       void (*shutdown)(struct writer_node *);
 };
 
 /**
@@ -97,6 +110,8 @@ struct writer_node_group {
        int *input_eof;
        int eof;
        char *buf;
+       unsigned int *channels;
+       unsigned int *samplerate;
        size_t *loaded;
        struct task task;
 };